Coverage for /home/kale/kxgames/libraries/vecrec/vecrec/__init__: 0%

# Coverage for /home/kale/kxgames/libraries/vecrec/vecrec/__init__ : 0%

## 11 statements 0 run 11 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | #!/usr/bin/env python3 __version__ = '0.0.0' from .shapes import Shape, Vector, Rect from .shapes import cast_anything_to_vector from .shapes import cast_anything_to_rectangle from .shapes import cast_shape_to_rectangle from .shapes import accept_anything_as_vector from .shapes import accept_anything_as_rectangle from .shapes import accept_shape_as_rectangle from .shapes import golden_ratio from .shapes import get_distance from .shapes import interpolate